@@ -68,7 +68,7 @@ def extract_array(input_csv_dir, col_to_be_predicted_idx):
     X, Y = extract_inputs(input_csv_dir, col_to_be_predicted_idx)
     X_original = np.array(X)
     Y_original = np.array(Y)
-    return X_original, Y_original
+    return X, Y, X_original, Y_original
 
 # num_trials = 100
 # samples = 100
@@ -141,7 +141,7 @@ def retrain_search(model, input_csv_dir, num_trials, samples, sensitive_param_id
     fairness = [] 
     fairness.append(current_estimate)
     
-    X_original, Y_original = extract_array(input_csv_dir, col_to_be_predicted_idx)
+    X, Y, X_original, Y_original = extract_array(input_csv_dir, col_to_be_predicted_idx)
     X_retrain, Y_retrain = extract_inputs(input_csv_dir, col_to_be_predicted_idx)
     retrain_len = len(X_retrain)
     for i in range(7):
@@ -160,8 +160,8 @@ def retrain_search(model, input_csv_dir, num_trials, samples, sensitive_param_id
         for i in retraining_input_set:
             X_additional.append(X_retrain[i])
             Y_additional.append(Y_retrain[i])
-        retrained_model = retrain(X_original, Y_original, np.array(X_additional), np.array(Y_additional))
-        retrained_estimate = get_estimate(model, num_trials, samples, sensitive_param_idx, num_params, input_bounds)
+        retrained_model = retrain(current_model, X_original, Y_original, np.array(X_additional), np.array(Y_additional))
+        retrained_estimate = get_estimate(current_model, num_trials, samples, sensitive_param_idx, num_params, input_bounds)
         fairness.append(retrained_estimate)
         if (retrained_estimate > current_estimate):
             return current_model
@@ -173,11 +173,11 @@ def retrain_search(model, input_csv_dir, num_trials, samples, sensitive_param_id
     return current_model, fairness
 
 def retrain_sklearn(input_pkl_dir, improved_pkl_dir, input_csv_dir, num_trials, samples,\
-                            sensitive_param_idx, num_params, input_bounds):
+                            sensitive_param_idx, num_params, input_bounds, col_to_be_predicted_idx):
     
     original_model = joblib.load(input_pkl_dir)
     improved_model, fairness= retrain_search(original_model, input_csv_dir, num_trials, samples, \
-                                                sensitive_param_idx, num_params, input_bounds)
+                                                sensitive_param_idx, num_params, input_bounds, col_to_be_predicted_idx)
     # file_to_save_model = config.improved_classfier_name
 
     joblib.dump(improved_model, improved_pkl_dir)
