@@ -1,6 +1,6 @@
 from .Generate_Sklearn_Classifier import generate_sklearn_classifier
 from .Retrain_Sklearn import retrain_sklearn
 from .Sklearn_Estimation import get_fairness_estimation
-from .Aequitas_Fully_Directed_Sklearn import Aequitas_fully_directed_sklearn
+from .Aequitas_Fully_Directed_Sklearn import aequitas_fully_directed_sklearn
 
 from .run_Aequitas import run_Aequitas_fully_direct
\ No newline at end of file
